# Changelog

## 1.1.0 (2025-09-19)

Full Changelog: [v1.0.0...v1.1.0](https://github.com/legalesign/legalesign-rest-python/compare/v1.0.0...v1.1.0)

### Features

* **api:** manual updates ([1307dba](https://github.com/legalesign/legalesign-rest-python/commit/1307dba268c1534ae692d673626df485d58625a8))

## 1.0.0 (2025-09-19)

Full Changelog: [v0.3.0...v1.0.0](https://github.com/legalesign/legalesign-rest-python/compare/v0.3.0...v1.0.0)

## 0.3.0 (2025-09-19)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/legalesign/legalesign-rest-python/compare/v0.2.0...v0.3.0)

### Features

* **api:** manual updates ([178351d](https://github.com/legalesign/legalesign-rest-python/commit/178351dc08b44a57f0acec7f941abfe032feed3b))

## 0.2.0 (2025-09-19)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/legalesign/legalesign-rest-python/compare/v0.1.0...v0.2.0)

### Features

* **api:** manual updates ([e4f9e6b](https://github.com/legalesign/legalesign-rest-python/commit/e4f9e6bc20b80109820e424ca023a0810f2a477d))
* **api:** manual updates ([14390e5](https://github.com/legalesign/legalesign-rest-python/commit/14390e5c766511ac7b24d8c03e06ddaa6102f02d))

## 0.1.0 (2025-09-19)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/legalesign/legalesign-rest-python/compare/v0.0.1...v0.1.0)

### Features

* **api:** api update ([edfcc59](https://github.com/legalesign/legalesign-rest-python/commit/edfcc598e815c95949609b478dc282fde4fcb3f4))
* **api:** manual updates ([a2f6a45](https://github.com/legalesign/legalesign-rest-python/commit/a2f6a454d95b54dfbd73be4a75a4188f2a5f760c))
* **api:** manual updates ([9cec340](https://github.com/legalesign/legalesign-rest-python/commit/9cec340083e9194eed62e043e146e741c3c1b07a))


### Chores

* configure new SDK language ([344b444](https://github.com/legalesign/legalesign-rest-python/commit/344b4448026766f35a7538ba0d80b86db6d0abd4))
* **internal:** update pydantic dependency ([15cb7bb](https://github.com/legalesign/legalesign-rest-python/commit/15cb7bb6fe767a591b8ee7fad614bcdf5b427112))
* **types:** change optional parameter type from NotGiven to Omit ([fa74419](https://github.com/legalesign/legalesign-rest-python/commit/fa74419c25b044b92c6798b7e462f4f8ae0299c8))
* update SDK settings ([6a4ed0d](https://github.com/legalesign/legalesign-rest-python/commit/6a4ed0d330ef395b1014725facc1382ccd4c0c7e))
